@@ -9,15 +9,12 @@ import random
 import csv
 import os
 import time
-import oflib
 from itertools import product
 import matplotlib.pyplot as plt
 import itertools as itools
 import textwrap as tw
-from ofunc import bdm, mdl, cpt, mu
 from copy import deepcopy
 import multiprocessing as mp
-import time
 from functools import reduce
 
 
@@ -1139,13 +1136,12 @@ def test(arity=np.array([3]*8), samples=10000, alpha=0):
     plt.triplot(b[0,:],b[1,:])
     plt.scatter(zz[0,:],zz[1,:],s=.1)
     
-try: 
-    import oflib
-    cmdl=oflib.cext().mdl
-    cmu=oflib.cext().mu
-except OSError: 
+#try:
+#    cmdl=oflib.cext().mdl
+#    cmu=oflib.cext().mu
+#except OSError: 
     #print("Try running make")
-    pass
+    #pass
 
 class search:
     """ Methods for BN structure learning """
